use std::sync::Arc;

use post::{
    adapter::{
        controller::post_controller::{PostController, PostControllerImpl},
        gateway::post_repository_impl::PostRepositoryImpl,
    },
    application::use_case::get_all_post_info_use_case::GetAllPostInfoUseCaseImpl,
    framework::db::post_db_service_impl::PostDbServiceImpl,
};

pub struct Controllers {
    pub post_controller: Arc<dyn PostController>,
}

impl Controllers {
    pub fn new() -> Self {
        let post_db_service = Arc::new(PostDbServiceImpl::new());
        let post_repository = Arc::new(PostRepositoryImpl::new(post_db_service));
        let get_all_post_info_use_case = Arc::new(GetAllPostInfoUseCaseImpl::new(post_repository));
        let post_controller = Arc::new(PostControllerImpl::new(get_all_post_info_use_case));

        Self { post_controller }
    }
}
